RuiAppNavigator class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
pop<T>([T? result])
→ void
-
-
push<T>(Route<T> route)
→ Future<T?>
-
-
pushNamed<T>(String routeName, {Object? arguments})
→ Future<T?>
-
-
showConfirmDialog({required String title, required String content, String confirmText = 'OK', String cancelText = 'Cancel', VoidCallback? onConfirm, VoidCallback? onCancel})
→ Future<bool>
-
-
showErrorDialog(String message)
→ Future<void>
-
-
showInputDialog({required String title, required String hintText, String initialValue = '', String confirmText = 'OK', String cancelText = 'Cancel'})
→ Future<String?>
-
-
showOptionsChooseDialog<T>({required String title, required String content, required List<T> options, T? defaultOption, dynamic itemBuilder(T)?, VoidCallback? onConfirm, VoidCallback? onCancel})
→ Future<T?>
-
-
showToast(String message)
→ Future<void>
-